@@ -19,4 +19,5 @@ Todo:
 
 """
 
-from .predict_hinge import predict_hinge
\ No newline at end of file
+from .predict_hinge import predict_hinge, hinge_cli
+from .calculate_entropy import entropy_cli
\ No newline at end of file
